@@ -1,4 +1,4 @@
-# $Id: command.rb,v 1.81 2006/07/03 01:19:13 fdiary Exp $
+# $Id: command.rb,v 1.89 2007/06/23 18:50:41 fdiary Exp $
 # Copyright (C) 2002-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'timeout'
@@ -49,7 +49,7 @@ module Hiki
 
       @aliaswiki  = AliasWiki::new( @db.load( @conf.aliaswiki_name ) )
       @p = @aliaswiki.original_name(@p).to_euc if @p
-      
+
       options = @conf.options || Hash::new( '' )
       options['page'] = @p
       options['db']   = @db
@@ -59,9 +59,19 @@ module Hiki
       options['params'] = @params
 
       @plugin = Plugin::new( options, @conf )
-      @session_id = @cgi.cookies['session_id'][0]
-      if @session_id
-        @plugin.user = Hiki::Session::new( @conf, @session_id ).user
+      session_id = @cgi.cookies['session_id'][0]
+      if session_id
+        session = Hiki::Session::new( @conf, session_id )
+        if session.check
+          @plugin.user = session.user
+          @plugin.session_id = session_id
+        end
+      end
+      if @conf.use_session && !@plugin.session_id
+        session = Hiki::Session::new( @conf )
+        session.save
+        @plugin.session_id = session.session_id
+        @plugin.add_cookie( session_cookie( @plugin.session_id ))
       end
       @body_enter = @plugin.body_enter_proc
     end
@@ -69,6 +79,9 @@ module Hiki
     def dispatch
       begin
         Timeout.timeout(@conf.timeout) {
+          if 'POST' == @cgi.request_method
+            raise PermissionError, 'Permission denied' unless @plugin.postable?
+          end
           @cmd = 'view' unless @cmd
           raise if !@p && ['view', 'edit', 'diff', 'save'].index( @cmd )
           if @cmd == 'edit'
@@ -85,7 +98,7 @@ module Hiki
             else
               cmd_preview
             end
-          elsif @cmd == 'create'  
+          elsif @cmd == 'create'
             raise PermissionError, 'Permission denied' unless @plugin.editable?
             send( "cmd_#{@cmd}" )
           else
@@ -108,7 +121,7 @@ module Hiki
       @plugin.hiki_menu(data, @cmd)
       @plugin.title = data[:title]
       data[:cmd] = @cmd
-      data[:cgi_name] = @conf.cgi_name 
+      data[:cgi_name] = @conf.cgi_name
       data[:body_enter] = @body_enter
       data[:lang] = @conf.lang
       data[:header] = @plugin.header_proc
@@ -133,7 +146,7 @@ module Hiki
     def generate_error_page( data )
       @plugin.hiki_menu(data, @cmd)
       @plugin.title = title( 'Error' )
-      data[:cgi_name] = @conf.cgi_name 
+      data[:cgi_name] = @conf.cgi_name
       data[:view_title] = 'Error'
       data[:header] = @plugin.header_proc
       data[:frontpage] = @plugin.page_name( 'FrontPage' )
@@ -145,11 +158,11 @@ module Hiki
     end
 
     def cmd_preview
-      raise PermissionError if @session_id && @session_id != @cgi.params['session_id'][0]
+      raise PermissionError if @plugin.session_id && @plugin.session_id != @cgi['session_id']
       @cmd = 'preview'
       cmd_edit( @p, @params['contents'][0], @conf.msg_preview, @params['page_title'][0] )
     end
-    
+
     def cmd_view
       unless @db.exist?( @p )
         @cmd = 'create'
@@ -173,17 +186,18 @@ module Hiki
         end
       end
 
-      @db.set_references( @p, formatter.references )
-      @db.increment_hitcount( @p )
+      old_ref = @db.get_attribute( @p, :references )
+      new_ref = formatter.references 
+      @db.set_references( @p, new_ref ) if new_ref != old_ref
       ref = @db.get_references( @p )
 
       data = get_common_data( @db, @plugin, @conf )
-      
+
       pg_title = @plugin.page_name(@p)
-      
+
       data[:page_title]   = (@plugin.hiki_anchor( @p.escape, @p.escapeHTML ))
       data[:view_title]   = pg_title
-      data[:title]        = title( pg_title )
+      data[:title]        = title( pg_title.unescapeHTML )
       data[:toc]          = @plugin.toc_f ? toc : nil
       data[:body]         = formatter.apply_tdiary_theme(contents)
       data[:references]   = ref.collect! {|a| "[#{@plugin.hiki_anchor(a.escape, @plugin.page_name(a))}] " }.join
@@ -194,7 +208,7 @@ module Hiki
 
       generate_page( data )
     end
- 
+
     def hilighten(str, keywords)
       hilighted = str.dup
       keywords.each do |key|
@@ -226,16 +240,16 @@ module Hiki
       }
 
       data = get_common_data( @db, @plugin, @conf )
-      
+
       data[:title]     = title( @conf.msg_index )
       data[:updatelist] = list
-      
+
       generate_page( data )
     end
 
     def cmd_recent
       list, last_modified = get_recent
-      
+
       data = get_common_data( @db, @plugin, @conf )
 
       data[:title]      = title( @conf.msg_recent )
@@ -294,7 +308,7 @@ module Hiki
         differ = word_diff( old, new ).gsub( /\n/, "<br>\n" )
         link = @plugin.hiki_anchor( page.escape, page.escapeHTML )
       end
-      
+
       @cmd = 'edit'
 
       if rev = @params['r'][0]
@@ -304,7 +318,7 @@ module Hiki
         text = ( @db.load( page ) || '' ) unless text
       end
       md5hex = @params['md5hex'][0] || @db.md5hex( page )
-      
+
       @plugin.text = text
 
       data[:title]          = title( page )
@@ -323,7 +337,7 @@ module Hiki
       data[:update_timestamp] ||= ' checked'
       data[:page_title]     = page_title
       data[:form_proc]      = @plugin.form_proc
-      data[:session_id]     = @session_id || ''
+      data[:session_id]     = @plugin.session_id
 
       generate_page( data )
     end
@@ -332,7 +346,7 @@ module Hiki
       old = @db.load_backup( @p ) || ''
       new = @db.load( @p ) || ''
       differ = word_diff( old, new ).gsub( /\n/, "<br>\n" )
-      
+
       data = get_common_data( @db, @plugin, @conf )
 
       data[:title]        = title("#{@p} #{@conf.msg_diff}")
@@ -341,7 +355,7 @@ module Hiki
     end
 
     def cmd_save( page, text, md5hex, update_timestamp = true )
-      raise PermissionError if @session_id && @session_id != @cgi.params['session_id'][0]
+      raise PermissionError if @plugin.session_id && @plugin.session_id != @cgi['session_id']
       subject = ''
       if text.empty?
         @db.delete( page )
@@ -360,7 +374,7 @@ module Hiki
           cmd_edit( page, text, @conf.msg_duplicate_page_title )
           return
         end
-        
+
         if @plugin.save( page, text, md5hex, update_timestamp )
           keyword = @params['keyword'][0].split("\n").collect {|k|
             k.chomp.strip}.delete_if{|k| k.size == 0}
@@ -410,7 +424,7 @@ module Hiki
         data[:list]      = nil
         data[:method]  = 'get'
       end
-      
+
       generate_page( data )
     end
 
@@ -423,7 +437,7 @@ module Hiki
           cmd_create( @conf.msg_invalid_filename( @conf.max_name_size) )
           return
         end
-        
+
         @cmd = 'edit'
 
         orig_page = exist?(@p)
@@ -442,7 +456,7 @@ module Hiki
         data[:key]     = %Q|value="#{msg ?  @p.escapeHTML :  ''}"|
         data[:list]    = nil
         data[:method]  = 'get'
-        
+
         generate_page( data )
       end
     end
@@ -461,9 +475,9 @@ module Hiki
           session.user = @plugin.user
           session.save
           if page && !page.empty?
-            redirect(@cgi, @conf.base_url + @plugin.hiki_url( page ), session_cookie( session.session_id )) 
+            redirect(@cgi, @conf.base_url + @plugin.hiki_url( page ), session_cookie( session.session_id ))
           else
-            redirect(@cgi, @conf.index_url, session_cookie( session.session_id )) 
+            redirect(@cgi, @conf.index_url, session_cookie( session.session_id ))
           end
           return
         else
@@ -484,12 +498,12 @@ module Hiki
       raise PermissionError, 'Permission denied' unless @plugin.admin?
 
       data = get_common_data( @db, @plugin, @conf )
-      data[:key]            = @cgi.params['conf'][0] || 'default'
+      data[:key]            = ( @cgi.params['conf'][0] || 'default' ).escapeHTML
 
       data[:title]          = title( @conf.msg_admin )
-      data[:session_id]     = @session_id
+      data[:session_id]     = @plugin.session_id
       if @cgi.params['saveconf'][0]
-        raise PermissionError if @session_id && @session_id != @cgi.params['session_id'][0]
+        raise PermissionError if @plugin.session_id && @plugin.session_id != @cgi['session_id']
         data[:save_config]    = true
       end
       generate_page( data )
@@ -510,11 +524,11 @@ module Hiki
       if p != @p and p != nil
         return p
       end
-      
+
       if @db.exist?(page) and @p != page
         return page
       end
-      
+
       false
     end
 
