@@ -1,4 +1,4 @@
-# $Id: rss.rb,v 1.3 2005/03/03 15:53:56 fdiary Exp $
+# $Id: rss.rb,v 1.4 2005/09/06 06:08:29 fdiary Exp $
 # Copyright (C) 2003 Laurent Sansonetti <laurent@datarescue.be>
 
 def label_rss_recent
@@ -11,5 +11,6 @@ def label_rss_mode_title; 'Select the format.'; end
 def label_rss_mode_candidate
   [ 'unified diff',
     'word diff (digest)',
-    'word diff (full text)', ]
+    'word diff (full text)',
+    'HTML (full text)', ]
 end
