@@ -1,4 +1,4 @@
-# $Id: rss.rb,v 1.2 2005/06/08 06:02:38 fdiary Exp $
+# $Id: rss.rb,v 1.4 2005/09/06 06:08:29 fdiary Exp $
 # Copyright (C) 2003-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>
 
@@ -11,7 +11,9 @@ def label_rss_mode_title; 'RSS Υեޥå'; end
 def label_rss_mode_candidate
   [ 'unified diff ',
     'word diff  ()',
-    'word diff  (ʸ)', ]
+    'word diff  (ʸ)',
+    'HTML  (ʸ)',
+  ]
 end
 def label_rss_menu_title; 'RSS ˥塼ɽ'; end
 def label_rss_menu_candidate
