@@ -1,7 +1,5 @@
-# $Id$
+# $Id: rank.rb,v 1.6 2006/08/04 15:34:14 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
-# You can redistribute it and/or modify it under the terms of
-# the Ruby's licence.#
 
 def rank( n = 20 )
   n = n > 0 ? n : 0
@@ -10,7 +8,7 @@ def rank( n = 20 )
     b[b.keys[0]][:count] <=> a[a.keys[0]][:count]
   end
 
-  s = '<ul>'
+  s = "<ul>\n"
   c = 1
   
   l.each do |a|
@@ -18,11 +16,16 @@ def rank( n = 20 )
     name = a.keys[0]
     p = a[name]
     
-    t = "#{name.escapeHTML} (#{p[:count]})"
-    an = "<a href=\"#{$cgi_name }?#{name.escape}\" title=\"#{name.escapeHTML}\">#{t}</a>"
-    s << "<li>#{an}</li>"
+    t = "#{page_name(name)} (#{p[:count]})"
+    an = hiki_anchor( name.escape, t )
+    s << "<li>#{an}\n"
     c = c + 1
   end
-  s << '</ul>'
+  s << "</ul>\n"
   s
-end
\ No newline at end of file
+end
+
+add_body_leave_proc do
+  @db.increment_hitcount( @page )
+  ''
+end
