@@ -12,7 +12,7 @@ add_conf_proc( 'default', 'Preferenze base' ) do
       <p><input name="author_name" value="#{CGI::escapeHTML(@conf.author_name)}" size="40"></p>
       <h3 class="subtitle">Indirizzo email</h3>
       <p>Imposta il tuo indirizzo email.</p>
-      <p><input name="mail" value="#{CGI::escapeHTML(@conf.mail)}" size="40"></p>
+      <p><textarea name="mail" rows="4" cols="50">#{CGI::escapeHTML(@conf.mail.join("\n"))}</textarea></p>
       <h3 class="subtitle">Manda email per le modifiche.</h3>
       <p>Se  ABILITATO, l'email di notifica  inviata all'"Indirizzo email" delle preferenze di base via SMTP server(che  impostato in hikiconf.rb) quando una pagina  aggiornata. Se  DISABILITATO, l'email viene inviata.</p>
       <p><select name="mail_on_update">
