@@ -1,3 +1,23 @@
+def help_lineshelp_label
+   'Իٱ'
+end
+
+def help_wordshelp_label
+   'ʸٱ'
+end
+
+def help_tablehelp_label
+   'ɽٱ'
+end
+
+def help_pluginhelp_label
+   'ץ饰ٱ'
+end
+
+def help_mathhelp_label
+   'ٱ'
+end
+
 def help_heading_label
    'Ф'
 end
@@ -10,6 +30,22 @@ def help_numbered_label
    'ֹ'
 end
 
+def help_preformatted_label
+   ''
+end
+
+def help_quotation_label
+   ''
+end
+
+def help_comment_label
+   ''
+end
+
+def help_cancel_label
+   ''
+end
+
 def help_link_label
    ''
 end
@@ -34,8 +70,8 @@ def help_definition_label
    'Ѹ'
 end
 
-def help_table_label
-   'ɽ'
+def help_horizontal_label
+   'ʿ'
 end
 
 def help_cell_label
@@ -54,42 +90,6 @@ def help_columns_label
    'Ϣ'
 end
 
-def help_horizontal_label
-   'ʿ'
-end
-
-def help_multiplelines_label
-   'ʣԻ'
-end
-
-def help_preformatted_label
-   ''
-end
-
-def help_cancel_label
-   ''
-end
-
-def help_quotation_label
-   ''
-end
-
-def help_comment_label
-   ''
-end
-
-def help_math_label
-   ''
-end
-
-def help_display_label
-   'ǥץ쥤'
-end
-
-def help_inline_label
-   '饤'
-end
-
 def help_plugin_label
    'ץ饰'
 end
@@ -109,3 +109,11 @@ end
 def help_recent_label
    'Ƕ'
 end
+
+def help_display_label
+   'ǥץ쥤'
+end
+
+def help_inline_label
+   '饤'
+end
