@@ -1,4 +1,4 @@
-# $Id: html_formatter.rb,v 1.59 2006/01/30 14:49:18 yanagita Exp $
+# $Id: html_formatter.rb,v 1.61 2006/10/11 13:06:14 yanagita Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'hiki/util'
@@ -111,6 +111,8 @@ module Hiki
           status << :pre
         when PLUGIN_CLOSE_RE, LINK_CLOSE_RE, PRE_CLOSE_RE
           status.pop
+        when TAG_RE
+          # do nothing
         else
           if status.empty?
             yield( str )
@@ -121,7 +123,7 @@ module Hiki
       ret.join
     end
 
-    URI_RE = /\A#{URI.regexp( %w( http https ftp mailto ) )}\z/
+    URI_RE = /\A#{URI.regexp( %w( http https ftp file mailto ) )}\z/
 
     def replace_link( text )
       text.gsub( %r|<a href="(.+?)">(.+?)</a>| ) do |str|
